"""
This package implements various VASP Jobs and Error Handlers.
"""

__author__ = "Shyue Ping Ong"
__version__ = "0.1"
__maintainer__ = "Shyue Ping Ong"
__email__ = "ongsp@ucsd.edu"
__status__ = "Production"
__date__ = "2/4/13"
